from .metadata import TileMetadata
from typing import List


class Focus(TileMetadata):
    focus: float


class Histogram(TileMetadata):
    hist: List[int]


class MinMaxMean(TileMetadata):
    min: int
    max: int
    mean: int
    std: int



from .metadata import TileMetadata
from . import statistics


class Preview(TileMetadata):
    image: str


class Mini(TileMetadata):
    image: str


class Raw(TileMetadata):
    path: str


class Transform(TileMetadata):
    rotation: float
    x: float
    y: float


class Processed(TileMetadata):
    path: str



from pigeon import BaseMessage
from typing import Mapping, List, Any, Optional, Tuple
from datetime import datetime


class Complete(BaseMessage):
    montage_id: str
    tile_ids: List[str]
    acquisition_id: str
    start_time: datetime
    pixel_size: float
    rotation_angle: float
    aperture_centroid: Tuple[int, int]


class Minimap(BaseMessage):
    image: Optional[str]
    colorbar: str
    min: Optional[float]
    max: Optional[float]


class Minimaps(BaseMessage):
    montage_id: str
    montage: Minimap
    focus: Minimap



from pigeon import BaseMessage
from typing import List, Tuple, Optional
from pydantic import Field


class Vertex(BaseMessage):
    x: float
    y: float


class ROI(BaseMessage):
    vertices: List[Vertex]
    rotation_angle: float
    buffer_size: float = 0.0
    montage_id: str
    specimen_id: Optional[str] = None
    grid_id: Optional[str] = None
    section_id: Optional[str] = None
    metadata: Optional[dict] = None
    queue_position: Optional[int] = Field(
        None, description="Position in queue, None means set as current"
    )


class LoadROI(BaseMessage):
    specimen_id: str
    section_id: str
    grid_id: Optional[str] = None
    queue_position: Optional[int] = Field(
        None, description="Position in queue, None means set as current"
    )


class CreateROI(BaseMessage):
    center: Vertex
    width: float
    height: float
    rotation_angle: float = 0.0
    montage_id: str
    specimen_id: Optional[str] = None
    grid_id: Optional[str] = None
    section_id: Optional[str] = None
    queue_position: Optional[int] = Field(
        None, description="Position in queue, None means set as current"
    )



from TEM_comms.camera import Command
from pytest import mark


@mark.parametrize(
    "data",
    [
        {
            "montage_id": "a montage id",
            "tile_id": "a tile id",
            "row": 1,
            "column": 2,
            "overlap": 100,
        },
        {
            "montage_id": "a montage id",
            "tile_id": "a tile id",
            "row": 1,
            "column": 2,
            "overlap": 100,
            "darkfield": True,
        },
        {
            "montage_id": "a montage id",
            "tile_id": "a tile id",
            "row": 1,
            "column": 2,
            "overlap": 100,
            "brightfield": True,
        },
        {
            "montage_id": "a montage id",
            "tile_id": "a tile id",
            "row": 1,
            "column": 2,
            "overlap": 100,
            "lens_correction": False,
        },
    ],
)
def test_command(data):
    Command(**data)
